# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.criteria_pb2 import (
    DeviceInfo as google___ads___googleads___v2___common___criteria_pb2___DeviceInfo,
    GenderInfo as google___ads___googleads___v2___common___criteria_pb2___GenderInfo,
)

from google.ads.google_ads.v2.proto.enums.reach_plan_ad_length_pb2 import (
    ReachPlanAdLengthEnum as google___ads___googleads___v2___enums___reach_plan_ad_length_pb2___ReachPlanAdLengthEnum,
)

from google.ads.google_ads.v2.proto.enums.reach_plan_age_range_pb2 import (
    ReachPlanAgeRangeEnum as google___ads___googleads___v2___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ListPlannableLocationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListPlannableLocationsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class ListPlannableLocationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def plannable_locations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PlannableLocation]: ...

    def __init__(self,
        *,
        plannable_locations : typing___Optional[typing___Iterable[PlannableLocation]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListPlannableLocationsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"plannable_locations"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"plannable_locations",b"plannable_locations"]) -> None: ...

class PlannableLocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def parent_country_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        parent_country_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PlannableLocation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"id",u"name",u"parent_country_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"id",u"name",u"parent_country_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"id",b"id",u"name",b"name",u"parent_country_id",b"parent_country_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"id",b"id",u"name",b"name",u"parent_country_id",b"parent_country_id"]) -> None: ...

class ListPlannableProductsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def plannable_location_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        plannable_location_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListPlannableProductsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"plannable_location_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"plannable_location_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"plannable_location_id",b"plannable_location_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"plannable_location_id",b"plannable_location_id"]) -> None: ...

class ListPlannableProductsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def product_metadata(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ProductMetadata]: ...

    def __init__(self,
        *,
        product_metadata : typing___Optional[typing___Iterable[ProductMetadata]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListPlannableProductsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"product_metadata"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"product_metadata",b"product_metadata"]) -> None: ...

class ProductMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def plannable_product_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def plannable_targeting(self) -> PlannableTargeting: ...

    def __init__(self,
        *,
        plannable_product_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        plannable_targeting : typing___Optional[PlannableTargeting] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductMetadata: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"plannable_product_code",u"plannable_targeting"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"plannable_product_code",u"plannable_targeting"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"plannable_product_code",b"plannable_product_code",u"plannable_targeting",b"plannable_targeting"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"plannable_product_code",b"plannable_product_code",u"plannable_targeting",b"plannable_targeting"]) -> None: ...

class PlannableTargeting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    age_ranges = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v2___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRange]

    @property
    def genders(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___criteria_pb2___GenderInfo]: ...

    @property
    def devices(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___criteria_pb2___DeviceInfo]: ...

    def __init__(self,
        *,
        age_ranges : typing___Optional[typing___Iterable[google___ads___googleads___v2___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRange]] = None,
        genders : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___criteria_pb2___GenderInfo]] = None,
        devices : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___criteria_pb2___DeviceInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PlannableTargeting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"age_ranges",u"devices",u"genders"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"age_ranges",b"age_ranges",u"devices",b"devices",u"genders",b"genders"]) -> None: ...

class GenerateProductMixIdeasRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    @property
    def plannable_location_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def budget_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def preferences(self) -> Preferences: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        plannable_location_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        budget_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        preferences : typing___Optional[Preferences] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateProductMixIdeasRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"budget_micros",u"currency_code",u"plannable_location_id",u"preferences"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros",u"currency_code",u"customer_id",u"plannable_location_id",u"preferences"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"budget_micros",b"budget_micros",u"currency_code",b"currency_code",u"plannable_location_id",b"plannable_location_id",u"preferences",b"preferences"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros",b"budget_micros",u"currency_code",b"currency_code",u"customer_id",b"customer_id",u"plannable_location_id",b"plannable_location_id",u"preferences",b"preferences"]) -> None: ...

class Preferences(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ad_length = ... # type: google___ads___googleads___v2___enums___reach_plan_ad_length_pb2___ReachPlanAdLengthEnum.ReachPlanAdLength

    @property
    def is_skippable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def starts_with_sound(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def top_content_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def has_guaranteed_price(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        is_skippable : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        starts_with_sound : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ad_length : typing___Optional[google___ads___googleads___v2___enums___reach_plan_ad_length_pb2___ReachPlanAdLengthEnum.ReachPlanAdLength] = None,
        top_content_only : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        has_guaranteed_price : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Preferences: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"has_guaranteed_price",u"is_skippable",u"starts_with_sound",u"top_content_only"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_length",u"has_guaranteed_price",u"is_skippable",u"starts_with_sound",u"top_content_only"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"has_guaranteed_price",b"has_guaranteed_price",u"is_skippable",b"is_skippable",u"starts_with_sound",b"starts_with_sound",u"top_content_only",b"top_content_only"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_length",b"ad_length",u"has_guaranteed_price",b"has_guaranteed_price",u"is_skippable",b"is_skippable",u"starts_with_sound",b"starts_with_sound",u"top_content_only",b"top_content_only"]) -> None: ...

class GenerateProductMixIdeasResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def product_allocation(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ProductAllocation]: ...

    def __init__(self,
        *,
        product_allocation : typing___Optional[typing___Iterable[ProductAllocation]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateProductMixIdeasResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"product_allocation"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"product_allocation",b"product_allocation"]) -> None: ...

class ProductAllocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def plannable_product_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def budget_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        plannable_product_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        budget_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductAllocation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"budget_micros",u"plannable_product_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros",u"plannable_product_code"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"budget_micros",b"budget_micros",u"plannable_product_code",b"plannable_product_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros",b"budget_micros",u"plannable_product_code",b"plannable_product_code"]) -> None: ...

class GenerateReachForecastRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign_duration(self) -> CampaignDuration: ...

    @property
    def cookie_frequency_cap(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def min_effective_frequency(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def targeting(self) -> Targeting: ...

    @property
    def planned_products(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PlannedProduct]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        campaign_duration : typing___Optional[CampaignDuration] = None,
        cookie_frequency_cap : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        min_effective_frequency : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        targeting : typing___Optional[Targeting] = None,
        planned_products : typing___Optional[typing___Iterable[PlannedProduct]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateReachForecastRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_duration",u"cookie_frequency_cap",u"currency_code",u"min_effective_frequency",u"targeting"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_duration",u"cookie_frequency_cap",u"currency_code",u"customer_id",u"min_effective_frequency",u"planned_products",u"targeting"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_duration",b"campaign_duration",u"cookie_frequency_cap",b"cookie_frequency_cap",u"currency_code",b"currency_code",u"min_effective_frequency",b"min_effective_frequency",u"targeting",b"targeting"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_duration",b"campaign_duration",u"cookie_frequency_cap",b"cookie_frequency_cap",u"currency_code",b"currency_code",u"customer_id",b"customer_id",u"min_effective_frequency",b"min_effective_frequency",u"planned_products",b"planned_products",u"targeting",b"targeting"]) -> None: ...

class Targeting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    age_range = ... # type: google___ads___googleads___v2___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRange

    @property
    def plannable_location_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def genders(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___criteria_pb2___GenderInfo]: ...

    @property
    def devices(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___criteria_pb2___DeviceInfo]: ...

    def __init__(self,
        *,
        plannable_location_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        age_range : typing___Optional[google___ads___googleads___v2___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRange] = None,
        genders : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___criteria_pb2___GenderInfo]] = None,
        devices : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___criteria_pb2___DeviceInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Targeting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"plannable_location_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"age_range",u"devices",u"genders",u"plannable_location_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"plannable_location_id",b"plannable_location_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"age_range",b"age_range",u"devices",b"devices",u"genders",b"genders",u"plannable_location_id",b"plannable_location_id"]) -> None: ...

class CampaignDuration(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def duration_in_days(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    def __init__(self,
        *,
        duration_in_days : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignDuration: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"duration_in_days"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"duration_in_days"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"duration_in_days",b"duration_in_days"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"duration_in_days",b"duration_in_days"]) -> None: ...

class PlannedProduct(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def plannable_product_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def budget_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        plannable_product_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        budget_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PlannedProduct: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"budget_micros",u"plannable_product_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros",u"plannable_product_code"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"budget_micros",b"budget_micros",u"plannable_product_code",b"plannable_product_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros",b"budget_micros",u"plannable_product_code",b"plannable_product_code"]) -> None: ...

class GenerateReachForecastResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def on_target_audience_metrics(self) -> OnTargetAudienceMetrics: ...

    @property
    def reach_curve(self) -> ReachCurve: ...

    def __init__(self,
        *,
        on_target_audience_metrics : typing___Optional[OnTargetAudienceMetrics] = None,
        reach_curve : typing___Optional[ReachCurve] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateReachForecastResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"on_target_audience_metrics",u"reach_curve"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"on_target_audience_metrics",u"reach_curve"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"on_target_audience_metrics",b"on_target_audience_metrics",u"reach_curve",b"reach_curve"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"on_target_audience_metrics",b"on_target_audience_metrics",u"reach_curve",b"reach_curve"]) -> None: ...

class ReachCurve(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def reach_forecasts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ReachForecast]: ...

    def __init__(self,
        *,
        reach_forecasts : typing___Optional[typing___Iterable[ReachForecast]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ReachCurve: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"reach_forecasts"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"reach_forecasts",b"reach_forecasts"]) -> None: ...

class ReachForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def forecast(self) -> Forecast: ...

    @property
    def forecasted_product_allocations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ProductAllocation]: ...

    def __init__(self,
        *,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        forecast : typing___Optional[Forecast] = None,
        forecasted_product_allocations : typing___Optional[typing___Iterable[ProductAllocation]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ReachForecast: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cost_micros",u"forecast"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cost_micros",u"forecast",u"forecasted_product_allocations"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cost_micros",b"cost_micros",u"forecast",b"forecast"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cost_micros",b"cost_micros",u"forecast",b"forecast",u"forecasted_product_allocations",b"forecasted_product_allocations"]) -> None: ...

class Forecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def on_target_reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def total_reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def on_target_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def total_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        on_target_reach : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        total_reach : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        on_target_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        total_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Forecast: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"on_target_impressions",u"on_target_reach",u"total_impressions",u"total_reach"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"on_target_impressions",u"on_target_reach",u"total_impressions",u"total_reach"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"on_target_impressions",b"on_target_impressions",u"on_target_reach",b"on_target_reach",u"total_impressions",b"total_impressions",u"total_reach",b"total_reach"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"on_target_impressions",b"on_target_impressions",u"on_target_reach",b"on_target_reach",u"total_impressions",b"total_impressions",u"total_reach",b"total_reach"]) -> None: ...

class OnTargetAudienceMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def youtube_audience_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def census_audience_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        youtube_audience_size : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        census_audience_size : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> OnTargetAudienceMetrics: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"census_audience_size",u"youtube_audience_size"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"census_audience_size",u"youtube_audience_size"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"census_audience_size",b"census_audience_size",u"youtube_audience_size",b"youtube_audience_size"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"census_audience_size",b"census_audience_size",u"youtube_audience_size",b"youtube_audience_size"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.resources.asset_pb2 import (
    Asset as google___ads___googleads___v1___resources___asset_pb2___Asset,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetAssetRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetAssetRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateAssetsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    @property
    def operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[AssetOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operations : typing___Optional[typing___Iterable[AssetOperation]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateAssetsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operations"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operations",b"operations"]) -> None: ...

class AssetOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def create(self) -> google___ads___googleads___v1___resources___asset_pb2___Asset: ...

    def __init__(self,
        *,
        create : typing___Optional[google___ads___googleads___v1___resources___asset_pb2___Asset] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AssetOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"create",u"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",u"operation"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["create"]: ...

class MutateAssetsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateAssetResult]: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[MutateAssetResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateAssetsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"results"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"results",b"results"]) -> None: ...

class MutateAssetResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateAssetResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CustomerManagerLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CustomerManagerLinkError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CustomerManagerLinkErrorEnum.CustomerManagerLinkError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CustomerManagerLinkErrorEnum.CustomerManagerLinkError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CustomerManagerLinkErrorEnum.CustomerManagerLinkError]]: ...
        UNSPECIFIED = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 0)
        UNKNOWN = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 1)
        NO_PENDING_INVITE = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 2)
        SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 3)
        MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 4)
        CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 5)
        CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 6)
        CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 7)
        CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 8)
        DUPLICATE_CHILD_FOUND = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 9)
    UNSPECIFIED = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 0)
    UNKNOWN = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 1)
    NO_PENDING_INVITE = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 2)
    SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 3)
    MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 4)
    CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 5)
    CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 6)
    CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 7)
    CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 8)
    DUPLICATE_CHILD_FOUND = typing___cast(CustomerManagerLinkErrorEnum.CustomerManagerLinkError, 9)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomerManagerLinkErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class UserListErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class UserListError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> UserListErrorEnum.UserListError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[UserListErrorEnum.UserListError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, UserListErrorEnum.UserListError]]: ...
        UNSPECIFIED = typing___cast(UserListErrorEnum.UserListError, 0)
        UNKNOWN = typing___cast(UserListErrorEnum.UserListError, 1)
        EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListError, 2)
        CONCRETE_TYPE_REQUIRED = typing___cast(UserListErrorEnum.UserListError, 3)
        CONVERSION_TYPE_ID_REQUIRED = typing___cast(UserListErrorEnum.UserListError, 4)
        DUPLICATE_CONVERSION_TYPES = typing___cast(UserListErrorEnum.UserListError, 5)
        INVALID_CONVERSION_TYPE = typing___cast(UserListErrorEnum.UserListError, 6)
        INVALID_DESCRIPTION = typing___cast(UserListErrorEnum.UserListError, 7)
        INVALID_NAME = typing___cast(UserListErrorEnum.UserListError, 8)
        INVALID_TYPE = typing___cast(UserListErrorEnum.UserListError, 9)
        CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = typing___cast(UserListErrorEnum.UserListError, 10)
        INVALID_USER_LIST_LOGICAL_RULE_OPERAND = typing___cast(UserListErrorEnum.UserListError, 11)
        NAME_ALREADY_USED = typing___cast(UserListErrorEnum.UserListError, 12)
        NEW_CONVERSION_TYPE_NAME_REQUIRED = typing___cast(UserListErrorEnum.UserListError, 13)
        CONVERSION_TYPE_NAME_ALREADY_USED = typing___cast(UserListErrorEnum.UserListError, 14)
        OWNERSHIP_REQUIRED_FOR_SET = typing___cast(UserListErrorEnum.UserListError, 15)
        USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListError, 16)
        INVALID_RULE = typing___cast(UserListErrorEnum.UserListError, 17)
        INVALID_DATE_RANGE = typing___cast(UserListErrorEnum.UserListError, 27)
        CAN_NOT_MUTATE_SENSITIVE_USERLIST = typing___cast(UserListErrorEnum.UserListError, 28)
        MAX_NUM_RULEBASED_USERLISTS = typing___cast(UserListErrorEnum.UserListError, 29)
        CANNOT_MODIFY_BILLABLE_RECORD_COUNT = typing___cast(UserListErrorEnum.UserListError, 30)
        APP_ID_NOT_SET = typing___cast(UserListErrorEnum.UserListError, 31)
        USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = typing___cast(UserListErrorEnum.UserListError, 32)
        ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = typing___cast(UserListErrorEnum.UserListError, 33)
        RULE_TYPE_IS_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListError, 34)
        CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = typing___cast(UserListErrorEnum.UserListError, 35)
        CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = typing___cast(UserListErrorEnum.UserListError, 36)
    UNSPECIFIED = typing___cast(UserListErrorEnum.UserListError, 0)
    UNKNOWN = typing___cast(UserListErrorEnum.UserListError, 1)
    EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListError, 2)
    CONCRETE_TYPE_REQUIRED = typing___cast(UserListErrorEnum.UserListError, 3)
    CONVERSION_TYPE_ID_REQUIRED = typing___cast(UserListErrorEnum.UserListError, 4)
    DUPLICATE_CONVERSION_TYPES = typing___cast(UserListErrorEnum.UserListError, 5)
    INVALID_CONVERSION_TYPE = typing___cast(UserListErrorEnum.UserListError, 6)
    INVALID_DESCRIPTION = typing___cast(UserListErrorEnum.UserListError, 7)
    INVALID_NAME = typing___cast(UserListErrorEnum.UserListError, 8)
    INVALID_TYPE = typing___cast(UserListErrorEnum.UserListError, 9)
    CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = typing___cast(UserListErrorEnum.UserListError, 10)
    INVALID_USER_LIST_LOGICAL_RULE_OPERAND = typing___cast(UserListErrorEnum.UserListError, 11)
    NAME_ALREADY_USED = typing___cast(UserListErrorEnum.UserListError, 12)
    NEW_CONVERSION_TYPE_NAME_REQUIRED = typing___cast(UserListErrorEnum.UserListError, 13)
    CONVERSION_TYPE_NAME_ALREADY_USED = typing___cast(UserListErrorEnum.UserListError, 14)
    OWNERSHIP_REQUIRED_FOR_SET = typing___cast(UserListErrorEnum.UserListError, 15)
    USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListError, 16)
    INVALID_RULE = typing___cast(UserListErrorEnum.UserListError, 17)
    INVALID_DATE_RANGE = typing___cast(UserListErrorEnum.UserListError, 27)
    CAN_NOT_MUTATE_SENSITIVE_USERLIST = typing___cast(UserListErrorEnum.UserListError, 28)
    MAX_NUM_RULEBASED_USERLISTS = typing___cast(UserListErrorEnum.UserListError, 29)
    CANNOT_MODIFY_BILLABLE_RECORD_COUNT = typing___cast(UserListErrorEnum.UserListError, 30)
    APP_ID_NOT_SET = typing___cast(UserListErrorEnum.UserListError, 31)
    USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = typing___cast(UserListErrorEnum.UserListError, 32)
    ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = typing___cast(UserListErrorEnum.UserListError, 33)
    RULE_TYPE_IS_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListError, 34)
    CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = typing___cast(UserListErrorEnum.UserListError, 35)
    CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = typing___cast(UserListErrorEnum.UserListError, 36)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.resources.ad_group_ad_label_pb2 import (
    AdGroupAdLabel as google___ads___googleads___v2___resources___ad_group_ad_label_pb2___AdGroupAdLabel,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetAdGroupAdLabelRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetAdGroupAdLabelRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateAdGroupAdLabelsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[AdGroupAdLabelOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operations : typing___Optional[typing___Iterable[AdGroupAdLabelOperation]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateAdGroupAdLabelsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operations",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operations",b"operations",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class AdGroupAdLabelOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove = ... # type: typing___Text

    @property
    def create(self) -> google___ads___googleads___v2___resources___ad_group_ad_label_pb2___AdGroupAdLabel: ...

    def __init__(self,
        *,
        create : typing___Optional[google___ads___googleads___v2___resources___ad_group_ad_label_pb2___AdGroupAdLabel] = None,
        remove : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupAdLabelOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"remove"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"remove"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"remove",b"remove"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"remove",b"remove"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["create","remove"]: ...

class MutateAdGroupAdLabelsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateAdGroupAdLabelResult]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        results : typing___Optional[typing___Iterable[MutateAdGroupAdLabelResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateAdGroupAdLabelsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class MutateAdGroupAdLabelResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateAdGroupAdLabelResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class BillingSetupErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class BillingSetupError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> BillingSetupErrorEnum.BillingSetupError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[BillingSetupErrorEnum.BillingSetupError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, BillingSetupErrorEnum.BillingSetupError]]: ...
        UNSPECIFIED = typing___cast(BillingSetupErrorEnum.BillingSetupError, 0)
        UNKNOWN = typing___cast(BillingSetupErrorEnum.BillingSetupError, 1)
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = typing___cast(BillingSetupErrorEnum.BillingSetupError, 2)
        CANNOT_REMOVE_STARTED_BILLING_SETUP = typing___cast(BillingSetupErrorEnum.BillingSetupError, 3)
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = typing___cast(BillingSetupErrorEnum.BillingSetupError, 4)
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = typing___cast(BillingSetupErrorEnum.BillingSetupError, 5)
        INVALID_PAYMENTS_ACCOUNT = typing___cast(BillingSetupErrorEnum.BillingSetupError, 6)
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = typing___cast(BillingSetupErrorEnum.BillingSetupError, 7)
        INVALID_START_TIME_TYPE = typing___cast(BillingSetupErrorEnum.BillingSetupError, 8)
        THIRD_PARTY_ALREADY_HAS_BILLING = typing___cast(BillingSetupErrorEnum.BillingSetupError, 9)
        BILLING_SETUP_IN_PROGRESS = typing___cast(BillingSetupErrorEnum.BillingSetupError, 10)
        NO_SIGNUP_PERMISSION = typing___cast(BillingSetupErrorEnum.BillingSetupError, 11)
        CHANGE_OF_BILL_TO_IN_PROGRESS = typing___cast(BillingSetupErrorEnum.BillingSetupError, 12)
        PAYMENTS_PROFILE_NOT_FOUND = typing___cast(BillingSetupErrorEnum.BillingSetupError, 13)
        PAYMENTS_ACCOUNT_NOT_FOUND = typing___cast(BillingSetupErrorEnum.BillingSetupError, 14)
        PAYMENTS_PROFILE_INELIGIBLE = typing___cast(BillingSetupErrorEnum.BillingSetupError, 15)
        PAYMENTS_ACCOUNT_INELIGIBLE = typing___cast(BillingSetupErrorEnum.BillingSetupError, 16)
        CUSTOMER_NEEDS_INTERNAL_APPROVAL = typing___cast(BillingSetupErrorEnum.BillingSetupError, 17)
    UNSPECIFIED = typing___cast(BillingSetupErrorEnum.BillingSetupError, 0)
    UNKNOWN = typing___cast(BillingSetupErrorEnum.BillingSetupError, 1)
    CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = typing___cast(BillingSetupErrorEnum.BillingSetupError, 2)
    CANNOT_REMOVE_STARTED_BILLING_SETUP = typing___cast(BillingSetupErrorEnum.BillingSetupError, 3)
    CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = typing___cast(BillingSetupErrorEnum.BillingSetupError, 4)
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = typing___cast(BillingSetupErrorEnum.BillingSetupError, 5)
    INVALID_PAYMENTS_ACCOUNT = typing___cast(BillingSetupErrorEnum.BillingSetupError, 6)
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = typing___cast(BillingSetupErrorEnum.BillingSetupError, 7)
    INVALID_START_TIME_TYPE = typing___cast(BillingSetupErrorEnum.BillingSetupError, 8)
    THIRD_PARTY_ALREADY_HAS_BILLING = typing___cast(BillingSetupErrorEnum.BillingSetupError, 9)
    BILLING_SETUP_IN_PROGRESS = typing___cast(BillingSetupErrorEnum.BillingSetupError, 10)
    NO_SIGNUP_PERMISSION = typing___cast(BillingSetupErrorEnum.BillingSetupError, 11)
    CHANGE_OF_BILL_TO_IN_PROGRESS = typing___cast(BillingSetupErrorEnum.BillingSetupError, 12)
    PAYMENTS_PROFILE_NOT_FOUND = typing___cast(BillingSetupErrorEnum.BillingSetupError, 13)
    PAYMENTS_ACCOUNT_NOT_FOUND = typing___cast(BillingSetupErrorEnum.BillingSetupError, 14)
    PAYMENTS_PROFILE_INELIGIBLE = typing___cast(BillingSetupErrorEnum.BillingSetupError, 15)
    PAYMENTS_ACCOUNT_INELIGIBLE = typing___cast(BillingSetupErrorEnum.BillingSetupError, 16)
    CUSTOMER_NEEDS_INTERNAL_APPROVAL = typing___cast(BillingSetupErrorEnum.BillingSetupError, 17)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BillingSetupErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignDraftErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignDraftError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignDraftErrorEnum.CampaignDraftError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignDraftErrorEnum.CampaignDraftError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignDraftErrorEnum.CampaignDraftError]]: ...
        UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 0)
        UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 1)
        DUPLICATE_DRAFT_NAME = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 2)
        INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 3)
        INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 4)
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 5)
        CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 6)
        CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 7)
        INVALID_DRAFT_CHANGE = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 8)
        INVALID_STATUS_TRANSITION = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 9)
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 10)
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 11)
    UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 0)
    UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 1)
    DUPLICATE_DRAFT_NAME = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 2)
    INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 3)
    INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 4)
    INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 5)
    CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 6)
    CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 7)
    INVALID_DRAFT_CHANGE = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 8)
    INVALID_STATUS_TRANSITION = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 9)
    MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 10)
    LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignDraftErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.budget_delivery_method_pb2 import (
    BudgetDeliveryMethodEnum as google___ads___googleads___v2___enums___budget_delivery_method_pb2___BudgetDeliveryMethodEnum,
)

from google.ads.google_ads.v2.proto.enums.budget_period_pb2 import (
    BudgetPeriodEnum as google___ads___googleads___v2___enums___budget_period_pb2___BudgetPeriodEnum,
)

from google.ads.google_ads.v2.proto.enums.budget_status_pb2 import (
    BudgetStatusEnum as google___ads___googleads___v2___enums___budget_status_pb2___BudgetStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.budget_type_pb2 import (
    BudgetTypeEnum as google___ads___googleads___v2___enums___budget_type_pb2___BudgetTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CampaignBudget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v2___enums___budget_status_pb2___BudgetStatusEnum.BudgetStatus
    delivery_method = ... # type: google___ads___googleads___v2___enums___budget_delivery_method_pb2___BudgetDeliveryMethodEnum.BudgetDeliveryMethod
    period = ... # type: google___ads___googleads___v2___enums___budget_period_pb2___BudgetPeriodEnum.BudgetPeriod
    type = ... # type: google___ads___googleads___v2___enums___budget_type_pb2___BudgetTypeEnum.BudgetType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def total_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def explicitly_shared(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def reference_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def has_recommended_budget(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def recommended_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def recommended_budget_estimated_change_weekly_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def recommended_budget_estimated_change_weekly_cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def recommended_budget_estimated_change_weekly_interactions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def recommended_budget_estimated_change_weekly_views(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        total_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___budget_status_pb2___BudgetStatusEnum.BudgetStatus] = None,
        delivery_method : typing___Optional[google___ads___googleads___v2___enums___budget_delivery_method_pb2___BudgetDeliveryMethodEnum.BudgetDeliveryMethod] = None,
        explicitly_shared : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        reference_count : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        has_recommended_budget : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        recommended_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        period : typing___Optional[google___ads___googleads___v2___enums___budget_period_pb2___BudgetPeriodEnum.BudgetPeriod] = None,
        recommended_budget_estimated_change_weekly_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        recommended_budget_estimated_change_weekly_cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        recommended_budget_estimated_change_weekly_interactions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        recommended_budget_estimated_change_weekly_views : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___budget_type_pb2___BudgetTypeEnum.BudgetType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignBudget: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"amount_micros",u"explicitly_shared",u"has_recommended_budget",u"id",u"name",u"recommended_budget_amount_micros",u"recommended_budget_estimated_change_weekly_clicks",u"recommended_budget_estimated_change_weekly_cost_micros",u"recommended_budget_estimated_change_weekly_interactions",u"recommended_budget_estimated_change_weekly_views",u"reference_count",u"total_amount_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"amount_micros",u"delivery_method",u"explicitly_shared",u"has_recommended_budget",u"id",u"name",u"period",u"recommended_budget_amount_micros",u"recommended_budget_estimated_change_weekly_clicks",u"recommended_budget_estimated_change_weekly_cost_micros",u"recommended_budget_estimated_change_weekly_interactions",u"recommended_budget_estimated_change_weekly_views",u"reference_count",u"resource_name",u"status",u"total_amount_micros",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"amount_micros",b"amount_micros",u"explicitly_shared",b"explicitly_shared",u"has_recommended_budget",b"has_recommended_budget",u"id",b"id",u"name",b"name",u"recommended_budget_amount_micros",b"recommended_budget_amount_micros",u"recommended_budget_estimated_change_weekly_clicks",b"recommended_budget_estimated_change_weekly_clicks",u"recommended_budget_estimated_change_weekly_cost_micros",b"recommended_budget_estimated_change_weekly_cost_micros",u"recommended_budget_estimated_change_weekly_interactions",b"recommended_budget_estimated_change_weekly_interactions",u"recommended_budget_estimated_change_weekly_views",b"recommended_budget_estimated_change_weekly_views",u"reference_count",b"reference_count",u"total_amount_micros",b"total_amount_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"amount_micros",b"amount_micros",u"delivery_method",b"delivery_method",u"explicitly_shared",b"explicitly_shared",u"has_recommended_budget",b"has_recommended_budget",u"id",b"id",u"name",b"name",u"period",b"period",u"recommended_budget_amount_micros",b"recommended_budget_amount_micros",u"recommended_budget_estimated_change_weekly_clicks",b"recommended_budget_estimated_change_weekly_clicks",u"recommended_budget_estimated_change_weekly_cost_micros",b"recommended_budget_estimated_change_weekly_cost_micros",u"recommended_budget_estimated_change_weekly_interactions",b"recommended_budget_estimated_change_weekly_interactions",u"recommended_budget_estimated_change_weekly_views",b"recommended_budget_estimated_change_weekly_views",u"reference_count",b"reference_count",u"resource_name",b"resource_name",u"status",b"status",u"total_amount_micros",b"total_amount_micros",u"type",b"type"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import (
    MutateOperation as google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperation,
    MutateOperationResponse as google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperationResponse,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CreateMutateJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateMutateJobRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id"]) -> None: ...

class CreateMutateJobResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateMutateJobResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class GetMutateJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetMutateJobRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class RunMutateJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RunMutateJobRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class AddMutateJobOperationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    sequence_token = ... # type: typing___Text

    @property
    def mutate_operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperation]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        sequence_token : typing___Optional[typing___Text] = None,
        mutate_operations : typing___Optional[typing___Iterable[google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperation]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AddMutateJobOperationsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operations",u"resource_name",u"sequence_token"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operations",b"mutate_operations",u"resource_name",b"resource_name",u"sequence_token",b"sequence_token"]) -> None: ...

class AddMutateJobOperationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    total_operations = ... # type: int
    next_sequence_token = ... # type: typing___Text

    def __init__(self,
        *,
        total_operations : typing___Optional[int] = None,
        next_sequence_token : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AddMutateJobOperationsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"next_sequence_token",u"total_operations"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"next_sequence_token",b"next_sequence_token",u"total_operations",b"total_operations"]) -> None: ...

class ListMutateJobResultsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    page_token = ... # type: typing___Text
    page_size = ... # type: int

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        page_token : typing___Optional[typing___Text] = None,
        page_size : typing___Optional[int] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListMutateJobResultsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",u"page_token",u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",b"page_size",u"page_token",b"page_token",u"resource_name",b"resource_name"]) -> None: ...

class ListMutateJobResultsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token = ... # type: typing___Text

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateJobResult]: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[MutateJobResult]] = None,
        next_page_token : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListMutateJobResultsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"next_page_token",u"results"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"next_page_token",b"next_page_token",u"results",b"results"]) -> None: ...

class MutateJobResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operation_index = ... # type: int

    @property
    def mutate_operation_response(self) -> google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperationResponse: ...

    @property
    def status(self) -> google___rpc___status_pb2___Status: ...

    def __init__(self,
        *,
        operation_index : typing___Optional[int] = None,
        mutate_operation_response : typing___Optional[google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperationResponse] = None,
        status : typing___Optional[google___rpc___status_pb2___Status] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateJobResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",u"status"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",u"operation_index",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",b"mutate_operation_response",u"status",b"status"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",b"mutate_operation_response",u"operation_index",b"operation_index",u"status",b"status"]) -> None: ...



# Stubs for google.ads.google_ads.v2.proto.services.reach_plan_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class ReachPlanServiceStub:
    ListPlannableLocations: Any = ...
    ListPlannableProducts: Any = ...
    GenerateProductMixIdeas: Any = ...
    GenerateReachForecast: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ReachPlanServiceServicer:
    def ListPlannableLocations(self, request: Any, context: Any) -> None: ...
    def ListPlannableProducts(self, request: Any, context: Any) -> None: ...
    def GenerateProductMixIdeas(self, request: Any, context: Any) -> None: ...
    def GenerateReachForecast(self, request: Any, context: Any) -> None: ...

def add_ReachPlanServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignBudgetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignBudgetError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignBudgetErrorEnum.CampaignBudgetError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignBudgetErrorEnum.CampaignBudgetError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignBudgetErrorEnum.CampaignBudgetError]]: ...
        UNSPECIFIED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 0)
        UNKNOWN = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 1)
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 17)
        CAMPAIGN_BUDGET_REMOVED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 2)
        CAMPAIGN_BUDGET_IN_USE = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 3)
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 4)
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 6)
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 7)
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 8)
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 9)
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 10)
        DUPLICATE_NAME = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 11)
        MONEY_AMOUNT_IN_WRONG_CURRENCY = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 12)
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 13)
        MONEY_AMOUNT_TOO_LARGE = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 14)
        NEGATIVE_MONEY_AMOUNT = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 15)
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 16)
    UNSPECIFIED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 0)
    UNKNOWN = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 1)
    CAMPAIGN_BUDGET_CANNOT_BE_SHARED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 17)
    CAMPAIGN_BUDGET_REMOVED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 2)
    CAMPAIGN_BUDGET_IN_USE = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 3)
    CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 4)
    CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 6)
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 7)
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 8)
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 9)
    CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 10)
    DUPLICATE_NAME = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 11)
    MONEY_AMOUNT_IN_WRONG_CURRENCY = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 12)
    MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 13)
    MONEY_AMOUNT_TOO_LARGE = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 14)
    NEGATIVE_MONEY_AMOUNT = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 15)
    NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetError, 16)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignBudgetErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter,
)

from google.ads.google_ads.v1.proto.common.explorer_auto_optimizer_setting_pb2 import (
    ExplorerAutoOptimizerSetting as google___ads___googleads___v1___common___explorer_auto_optimizer_setting_pb2___ExplorerAutoOptimizerSetting,
)

from google.ads.google_ads.v1.proto.common.targeting_setting_pb2 import (
    TargetingSetting as google___ads___googleads___v1___common___targeting_setting_pb2___TargetingSetting,
)

from google.ads.google_ads.v1.proto.enums.ad_group_ad_rotation_mode_pb2 import (
    AdGroupAdRotationModeEnum as google___ads___googleads___v1___enums___ad_group_ad_rotation_mode_pb2___AdGroupAdRotationModeEnum,
)

from google.ads.google_ads.v1.proto.enums.ad_group_status_pb2 import (
    AdGroupStatusEnum as google___ads___googleads___v1___enums___ad_group_status_pb2___AdGroupStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.ad_group_type_pb2 import (
    AdGroupTypeEnum as google___ads___googleads___v1___enums___ad_group_type_pb2___AdGroupTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.bidding_source_pb2 import (
    BiddingSourceEnum as google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum,
)

from google.ads.google_ads.v1.proto.enums.targeting_dimension_pb2 import (
    TargetingDimensionEnum as google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroup(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v1___enums___ad_group_status_pb2___AdGroupStatusEnum.AdGroupStatus
    type = ... # type: google___ads___googleads___v1___enums___ad_group_type_pb2___AdGroupTypeEnum.AdGroupType
    ad_rotation_mode = ... # type: google___ads___googleads___v1___enums___ad_group_ad_rotation_mode_pb2___AdGroupAdRotationModeEnum.AdGroupAdRotationMode
    display_custom_bid_dimension = ... # type: google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimension
    effective_target_cpa_source = ... # type: google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource
    effective_target_roas_source = ... # type: google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def base_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpm_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def target_cpm_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def target_roas(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def percent_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def explorer_auto_optimizer_setting(self) -> google___ads___googleads___v1___common___explorer_auto_optimizer_setting_pb2___ExplorerAutoOptimizerSetting: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def targeting_setting(self) -> google___ads___googleads___v1___common___targeting_setting_pb2___TargetingSetting: ...

    @property
    def effective_target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def effective_target_roas(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___ad_group_status_pb2___AdGroupStatusEnum.AdGroupStatus] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___ad_group_type_pb2___AdGroupTypeEnum.AdGroupType] = None,
        ad_rotation_mode : typing___Optional[google___ads___googleads___v1___enums___ad_group_ad_rotation_mode_pb2___AdGroupAdRotationModeEnum.AdGroupAdRotationMode] = None,
        base_ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter]] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpm_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpv_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        target_cpm_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        target_roas : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        percent_cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        explorer_auto_optimizer_setting : typing___Optional[google___ads___googleads___v1___common___explorer_auto_optimizer_setting_pb2___ExplorerAutoOptimizerSetting] = None,
        display_custom_bid_dimension : typing___Optional[google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimension] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        targeting_setting : typing___Optional[google___ads___googleads___v1___common___targeting_setting_pb2___TargetingSetting] = None,
        effective_target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        effective_target_cpa_source : typing___Optional[google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource] = None,
        effective_target_roas : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        effective_target_roas_source : typing___Optional[google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroup: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"base_ad_group",u"campaign",u"cpc_bid_micros",u"cpm_bid_micros",u"cpv_bid_micros",u"effective_target_cpa_micros",u"effective_target_roas",u"explorer_auto_optimizer_setting",u"final_url_suffix",u"id",u"name",u"percent_cpc_bid_micros",u"target_cpa_micros",u"target_cpm_micros",u"target_roas",u"targeting_setting",u"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_rotation_mode",u"base_ad_group",u"campaign",u"cpc_bid_micros",u"cpm_bid_micros",u"cpv_bid_micros",u"display_custom_bid_dimension",u"effective_target_cpa_micros",u"effective_target_cpa_source",u"effective_target_roas",u"effective_target_roas_source",u"explorer_auto_optimizer_setting",u"final_url_suffix",u"id",u"name",u"percent_cpc_bid_micros",u"resource_name",u"status",u"target_cpa_micros",u"target_cpm_micros",u"target_roas",u"targeting_setting",u"tracking_url_template",u"type",u"url_custom_parameters"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"base_ad_group",b"base_ad_group",u"campaign",b"campaign",u"cpc_bid_micros",b"cpc_bid_micros",u"cpm_bid_micros",b"cpm_bid_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"effective_target_cpa_micros",b"effective_target_cpa_micros",u"effective_target_roas",b"effective_target_roas",u"explorer_auto_optimizer_setting",b"explorer_auto_optimizer_setting",u"final_url_suffix",b"final_url_suffix",u"id",b"id",u"name",b"name",u"percent_cpc_bid_micros",b"percent_cpc_bid_micros",u"target_cpa_micros",b"target_cpa_micros",u"target_cpm_micros",b"target_cpm_micros",u"target_roas",b"target_roas",u"targeting_setting",b"targeting_setting",u"tracking_url_template",b"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_rotation_mode",b"ad_rotation_mode",u"base_ad_group",b"base_ad_group",u"campaign",b"campaign",u"cpc_bid_micros",b"cpc_bid_micros",u"cpm_bid_micros",b"cpm_bid_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"display_custom_bid_dimension",b"display_custom_bid_dimension",u"effective_target_cpa_micros",b"effective_target_cpa_micros",u"effective_target_cpa_source",b"effective_target_cpa_source",u"effective_target_roas",b"effective_target_roas",u"effective_target_roas_source",b"effective_target_roas_source",u"explorer_auto_optimizer_setting",b"explorer_auto_optimizer_setting",u"final_url_suffix",b"final_url_suffix",u"id",b"id",u"name",b"name",u"percent_cpc_bid_micros",b"percent_cpc_bid_micros",u"resource_name",b"resource_name",u"status",b"status",u"target_cpa_micros",b"target_cpa_micros",u"target_cpm_micros",b"target_cpm_micros",u"target_roas",b"target_roas",u"targeting_setting",b"targeting_setting",u"tracking_url_template",b"tracking_url_template",u"type",b"type",u"url_custom_parameters",b"url_custom_parameters"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AuthorizationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AuthorizationError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AuthorizationErrorEnum.AuthorizationError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AuthorizationErrorEnum.AuthorizationError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AuthorizationErrorEnum.AuthorizationError]]: ...
        UNSPECIFIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 0)
        UNKNOWN = typing___cast(AuthorizationErrorEnum.AuthorizationError, 1)
        USER_PERMISSION_DENIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 2)
        DEVELOPER_TOKEN_NOT_WHITELISTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 3)
        DEVELOPER_TOKEN_PROHIBITED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 4)
        PROJECT_DISABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 5)
        AUTHORIZATION_ERROR = typing___cast(AuthorizationErrorEnum.AuthorizationError, 6)
        ACTION_NOT_PERMITTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 7)
        INCOMPLETE_SIGNUP = typing___cast(AuthorizationErrorEnum.AuthorizationError, 8)
        CUSTOMER_NOT_ENABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 24)
        MISSING_TOS = typing___cast(AuthorizationErrorEnum.AuthorizationError, 9)
        DEVELOPER_TOKEN_NOT_APPROVED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 10)
    UNSPECIFIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 0)
    UNKNOWN = typing___cast(AuthorizationErrorEnum.AuthorizationError, 1)
    USER_PERMISSION_DENIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 2)
    DEVELOPER_TOKEN_NOT_WHITELISTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 3)
    DEVELOPER_TOKEN_PROHIBITED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 4)
    PROJECT_DISABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 5)
    AUTHORIZATION_ERROR = typing___cast(AuthorizationErrorEnum.AuthorizationError, 6)
    ACTION_NOT_PERMITTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 7)
    INCOMPLETE_SIGNUP = typing___cast(AuthorizationErrorEnum.AuthorizationError, 8)
    CUSTOMER_NOT_ENABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 24)
    MISSING_TOS = typing___cast(AuthorizationErrorEnum.AuthorizationError, 9)
    DEVELOPER_TOKEN_NOT_APPROVED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 10)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AuthorizationErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.policy_topic_entry_type_pb2 import (
    PolicyTopicEntryTypeEnum as google___ads___googleads___v2___enums___policy_topic_entry_type_pb2___PolicyTopicEntryTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2 import (
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum as google___ads___googleads___v2___enums___policy_topic_evidence_destination_mismatch_url_type_pb2___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_topic_evidence_destination_not_working_device_pb2 import (
    PolicyTopicEvidenceDestinationNotWorkingDeviceEnum as google___ads___googleads___v2___enums___policy_topic_evidence_destination_not_working_device_pb2___PolicyTopicEvidenceDestinationNotWorkingDeviceEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_topic_evidence_destination_not_working_dns_error_type_pb2 import (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum as google___ads___googleads___v2___enums___policy_topic_evidence_destination_not_working_dns_error_type_pb2___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class PolicyViolationKey(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def policy_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def violating_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        policy_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        violating_text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyViolationKey: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"policy_name",u"violating_text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"policy_name",u"violating_text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"policy_name",b"policy_name",u"violating_text",b"violating_text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"policy_name",b"policy_name",u"violating_text",b"violating_text"]) -> None: ...

class PolicyValidationParameter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ignorable_policy_topics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def exempt_policy_violation_keys(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PolicyViolationKey]: ...

    def __init__(self,
        *,
        ignorable_policy_topics : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        exempt_policy_violation_keys : typing___Optional[typing___Iterable[PolicyViolationKey]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyValidationParameter: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"exempt_policy_violation_keys",u"ignorable_policy_topics"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"exempt_policy_violation_keys",b"exempt_policy_violation_keys",u"ignorable_policy_topics",b"ignorable_policy_topics"]) -> None: ...

class PolicyTopicEntry(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___policy_topic_entry_type_pb2___PolicyTopicEntryTypeEnum.PolicyTopicEntryType

    @property
    def topic(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def evidences(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PolicyTopicEvidence]: ...

    @property
    def constraints(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PolicyTopicConstraint]: ...

    def __init__(self,
        *,
        topic : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___policy_topic_entry_type_pb2___PolicyTopicEntryTypeEnum.PolicyTopicEntryType] = None,
        evidences : typing___Optional[typing___Iterable[PolicyTopicEvidence]] = None,
        constraints : typing___Optional[typing___Iterable[PolicyTopicConstraint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyTopicEntry: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"topic"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"constraints",u"evidences",u"topic",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"topic",b"topic"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"constraints",b"constraints",u"evidences",b"evidences",u"topic",b"topic",u"type",b"type"]) -> None: ...

class PolicyTopicEvidence(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class TextList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def texts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            texts : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicEvidence.TextList: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"texts"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"texts",b"texts"]) -> None: ...

    class WebsiteList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def websites(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            websites : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicEvidence.WebsiteList: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"websites"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"websites",b"websites"]) -> None: ...

    class DestinationTextList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def destination_texts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            destination_texts : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicEvidence.DestinationTextList: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"destination_texts"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"destination_texts",b"destination_texts"]) -> None: ...

    class DestinationMismatch(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        url_types = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v2___enums___policy_topic_evidence_destination_mismatch_url_type_pb2___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType]

        def __init__(self,
            *,
            url_types : typing___Optional[typing___Iterable[google___ads___googleads___v2___enums___policy_topic_evidence_destination_mismatch_url_type_pb2___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicEvidence.DestinationMismatch: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"url_types"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"url_types",b"url_types"]) -> None: ...

    class DestinationNotWorking(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        device = ... # type: google___ads___googleads___v2___enums___policy_topic_evidence_destination_not_working_device_pb2___PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDevice
        dns_error_type = ... # type: google___ads___googleads___v2___enums___policy_topic_evidence_destination_not_working_dns_error_type_pb2___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType

        @property
        def expanded_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def last_checked_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def http_error_code(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            expanded_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            device : typing___Optional[google___ads___googleads___v2___enums___policy_topic_evidence_destination_not_working_device_pb2___PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDevice] = None,
            last_checked_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            dns_error_type : typing___Optional[google___ads___googleads___v2___enums___policy_topic_evidence_destination_not_working_dns_error_type_pb2___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType] = None,
            http_error_code : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicEvidence.DestinationNotWorking: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"dns_error_type",u"expanded_url",u"http_error_code",u"last_checked_date_time",u"reason"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"device",u"dns_error_type",u"expanded_url",u"http_error_code",u"last_checked_date_time",u"reason"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"dns_error_type",b"dns_error_type",u"expanded_url",b"expanded_url",u"http_error_code",b"http_error_code",u"last_checked_date_time",b"last_checked_date_time",u"reason",b"reason"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"dns_error_type",b"dns_error_type",u"expanded_url",b"expanded_url",u"http_error_code",b"http_error_code",u"last_checked_date_time",b"last_checked_date_time",u"reason",b"reason"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions___Literal[u"reason",b"reason"]) -> typing_extensions___Literal["dns_error_type","http_error_code"]: ...


    @property
    def website_list(self) -> PolicyTopicEvidence.WebsiteList: ...

    @property
    def text_list(self) -> PolicyTopicEvidence.TextList: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def destination_text_list(self) -> PolicyTopicEvidence.DestinationTextList: ...

    @property
    def destination_mismatch(self) -> PolicyTopicEvidence.DestinationMismatch: ...

    @property
    def destination_not_working(self) -> PolicyTopicEvidence.DestinationNotWorking: ...

    def __init__(self,
        *,
        website_list : typing___Optional[PolicyTopicEvidence.WebsiteList] = None,
        text_list : typing___Optional[PolicyTopicEvidence.TextList] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        destination_text_list : typing___Optional[PolicyTopicEvidence.DestinationTextList] = None,
        destination_mismatch : typing___Optional[PolicyTopicEvidence.DestinationMismatch] = None,
        destination_not_working : typing___Optional[PolicyTopicEvidence.DestinationNotWorking] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyTopicEvidence: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"destination_mismatch",u"destination_not_working",u"destination_text_list",u"language_code",u"text_list",u"value",u"website_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"destination_mismatch",u"destination_not_working",u"destination_text_list",u"language_code",u"text_list",u"value",u"website_list"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"destination_mismatch",b"destination_mismatch",u"destination_not_working",b"destination_not_working",u"destination_text_list",b"destination_text_list",u"language_code",b"language_code",u"text_list",b"text_list",u"value",b"value",u"website_list",b"website_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"destination_mismatch",b"destination_mismatch",u"destination_not_working",b"destination_not_working",u"destination_text_list",b"destination_text_list",u"language_code",b"language_code",u"text_list",b"text_list",u"value",b"value",u"website_list",b"website_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"value",b"value"]) -> typing_extensions___Literal["website_list","text_list","language_code","destination_text_list","destination_mismatch","destination_not_working"]: ...

class PolicyTopicConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CountryConstraintList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def total_targeted_countries(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

        @property
        def countries(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PolicyTopicConstraint.CountryConstraint]: ...

        def __init__(self,
            *,
            total_targeted_countries : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
            countries : typing___Optional[typing___Iterable[PolicyTopicConstraint.CountryConstraint]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicConstraint.CountryConstraintList: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"total_targeted_countries"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"countries",u"total_targeted_countries"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"total_targeted_countries",b"total_targeted_countries"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"countries",b"countries",u"total_targeted_countries",b"total_targeted_countries"]) -> None: ...

    class ResellerConstraint(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        def __init__(self,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicConstraint.ResellerConstraint: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

    class CountryConstraint(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def country_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        def __init__(self,
            *,
            country_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> PolicyTopicConstraint.CountryConstraint: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"country_criterion"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"country_criterion"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"country_criterion",b"country_criterion"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"country_criterion",b"country_criterion"]) -> None: ...


    @property
    def country_constraint_list(self) -> PolicyTopicConstraint.CountryConstraintList: ...

    @property
    def reseller_constraint(self) -> PolicyTopicConstraint.ResellerConstraint: ...

    @property
    def certificate_missing_in_country_list(self) -> PolicyTopicConstraint.CountryConstraintList: ...

    @property
    def certificate_domain_mismatch_in_country_list(self) -> PolicyTopicConstraint.CountryConstraintList: ...

    def __init__(self,
        *,
        country_constraint_list : typing___Optional[PolicyTopicConstraint.CountryConstraintList] = None,
        reseller_constraint : typing___Optional[PolicyTopicConstraint.ResellerConstraint] = None,
        certificate_missing_in_country_list : typing___Optional[PolicyTopicConstraint.CountryConstraintList] = None,
        certificate_domain_mismatch_in_country_list : typing___Optional[PolicyTopicConstraint.CountryConstraintList] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyTopicConstraint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"certificate_domain_mismatch_in_country_list",u"certificate_missing_in_country_list",u"country_constraint_list",u"reseller_constraint",u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"certificate_domain_mismatch_in_country_list",u"certificate_missing_in_country_list",u"country_constraint_list",u"reseller_constraint",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"certificate_domain_mismatch_in_country_list",b"certificate_domain_mismatch_in_country_list",u"certificate_missing_in_country_list",b"certificate_missing_in_country_list",u"country_constraint_list",b"country_constraint_list",u"reseller_constraint",b"reseller_constraint",u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"certificate_domain_mismatch_in_country_list",b"certificate_domain_mismatch_in_country_list",u"certificate_missing_in_country_list",b"certificate_missing_in_country_list",u"country_constraint_list",b"country_constraint_list",u"reseller_constraint",b"reseller_constraint",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"value",b"value"]) -> typing_extensions___Literal["country_constraint_list","reseller_constraint","certificate_missing_in_country_list","certificate_domain_mismatch_in_country_list"]: ...
